.. colliderscope documentation master file, created by
   sphinx-quickstart on Thu Jan 13 12:21:01 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to colliderscope's documentation!
=========================================

.. mdinclude:: ../../README.md

.. toctree::
   :maxdepth: 2

   API Reference <api>
   CLI Reference <cli>
